import React, { useState, useEffect } from "react";
import { Link } from "react-router-dom";
import styles from "./NavbarStyles.module.css";

const Navbar = () => {
  // need to make the navbar dynamic based on if a person is logged in or not
  const [isLoggedIn, setIsLoggedIn] = useState(false); // initially logged out
  const [role, setRole] = useState(""); // keeps track of the user's role to see if we need to include admin tab

  useEffect(() => {
    // get the user's role
    const storedRole = localStorage.getItem("role");

    if (storedRole) {
      // logged in
      setIsLoggedIn(true);
      setRole(storedRole);
    } else {
      // not logged in
      setIsLoggedIn(false);
      setRole("");
    }
  }, []);

  const handleLogout = () => {
    // Clear local storage and log out
    localStorage.removeItem("userId");
    localStorage.removeItem("role");
    localStorage.removeItem("personId");
    setIsLoggedIn(false);
    setRole("");
  };

  return (
    <nav className={styles.navbar}>
      <ul className={styles.navList}>
        {/* Common Links */}
        <li>
          <Link
            to="/home"
            className={({ isActive }) => (isActive ? "active" : "")}
          >
            Home
          </Link>
        </li>
        <li>
          <Link
            to="/browse"
            className={({ isActive }) => (isActive ? "active" : "")}
          >
            Browse
          </Link>
        </li>
        <li>
          <Link
            to="/user/search-browse"
            className={({ isActive }) => (isActive ? "active" : "")}
          >
            Search
          </Link>
        </li>

        {/* Links for logged-out users */}
        {!isLoggedIn && (
          <li>
            <Link
              to="/login"
              className={({ isActive }) => (isActive ? "active" : "")}
            >
              Login
            </Link>
          </li>
        )}

        {/* Admin-specific Links */}
        {isLoggedIn &&
          (role === "admin" ||
            role === "classChampion" ||
            role === "orgLeader") && (
            <li>
              <Link
                to="/admin/dashboard"
                className={({ isActive }) => (isActive ? "active" : "")}
              >
                Admin
              </Link>
            </li>
          )}

        {/* Links for logged-in users */}
        {isLoggedIn && (
          <>
            <li>
              <Link
                to="/my-profile"
                className={({ isActive }) => (isActive ? "active" : "")}
              >
                My Profile
              </Link>
            </li>
            <li>
              <button onClick={handleLogout} className={styles.logoutButton}>
                Logout
              </button>
            </li>
          </>
        )}
      </ul>
    </nav>
  );
};

export default Navbar;
